# Generated by Django 3.2.18 on 2023-12-21 14:29

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("mozilla_django_oidc_db", "0012_alter_openidconnectconfig_sync_groups"),
        ("mozilla_django_oidc_db", "0012_openidconnectconfig_superuser_group_names"),
    ]

    operations = []
