# Generated by Django 3.2.23 on 2024-01-09 10:38

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("mozilla_django_oidc_db", "0013_merge_20231221_1529"),
    ]

    operations = [
        migrations.AlterField(
            model_name="openidconnectconfig",
            name="groups_claim",
            field=models.CharField(
                blank=True,
                default="roles",
                help_text="The name of the OIDC claim that holds the values to map to local user groups.",
                max_length=50,
                verbose_name="groups claim",
            ),
        ),
    ]
