# Generated by Django 3.2.18 on 2023-12-21 11:59

from django.db import migrations, models

import django_jsonform.models.fields


class Migration(migrations.Migration):
    dependencies = [
        (
            "mozilla_django_oidc_db",
            "0011_alter_openidconnectconfig_userinfo_claims_source",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="openidconnectconfig",
            name="superuser_group_names",
            field=django_jsonform.models.fields.ArrayField(
                base_field=models.CharField(
                    max_length=50, verbose_name="Superuser group name"
                ),
                blank=True,
                default=list,
                help_text="If any of these group names are present in the claims upon login, the user will be marked as a superuser. If none of these groups are present the user will lose superuser permissions.",
                size=None,
                verbose_name="Superuser group names",
            ),
        ),
    ]
