# Generated by Django 4.2.11 on 2024-07-01 15:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "mozilla_django_oidc_db",
            "0003_openidconnectconfig_oidc_keycloak_idp_hint_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="openidconnectconfig",
            name="oidc_exempt_urls",
        ),
    ]
